summaryrefslogtreecommitdiffstats
path: root/kbruch/src/exercisecompare.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kbruch/src/exercisecompare.cpp')
-rw-r--r--kbruch/src/exercisecompare.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/kbruch/src/exercisecompare.cpp b/kbruch/src/exercisecompare.cpp
index f6652e56..295698fb 100644
--- a/kbruch/src/exercisecompare.cpp
+++ b/kbruch/src/exercisecompare.cpp
@@ -22,7 +22,7 @@
#include <kapplication.h>
#include <klocale.h>
/* these includes are needed for Qt support */
#include <tqlabel.h>
#include <tqlayout.h>
#include <tqpushbutton.h>
@@ -35,8 +35,8 @@
/* ----- public member functions ----- */
/* constructor */
-ExerciseCompare::ExerciseCompare(TQWidget * parent, const char * name):
- ExerciseBase(parent, name)
+ExerciseCompare::ExerciseCompare(TQWidget * tqparent, const char * name):
+ ExerciseBase(tqparent, name)
{
#ifdef DEBUG
kdDebug() << "constructor ExerciseCompare()" << endl;
@@ -123,13 +123,13 @@ ExerciseCompare::ExerciseCompare(TQWidget * parent, const char * name):
m_checkButton->setText(i18n("&Check Task"));
m_checkButton->setDefault(true); // is the default button of the dialog
TQToolTip::add(m_checkButton, i18n("Click on this button to check your result."));
- lowerHBox->addWidget(m_checkButton, 1, Qt::AlignRight);
+ lowerHBox->addWidget(m_checkButton, 1, TQt::AlignRight);
TQObject::connect(m_checkButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotCheckButtonClicked()));
// that the user can start typing without moving the focus
m_signButton->setFocus();
- // show the whole layout
+ // show the whole tqlayout
baseWidget->show();
// add tooltip and qwhatsthis help to the widget
@@ -144,7 +144,7 @@ ExerciseCompare::~ExerciseCompare()
kdDebug() << "destructor ExerciseCompare()" << endl;
#endif
/* no need to delete any child widgets, Qt does it by itself */
}
/** resets the current state, creates a new task and count the last task as
@@ -300,10 +300,10 @@ void ExerciseCompare::slotCheckButtonClicked()
void ExerciseCompare::slotSignButtonClicked()
{
// in RTL desktops, we still need to allign the
- // execise to the left. On Qt4, you can set the direction
- // of the layout to LTR (instead of inherit), but on Qt3
+ // execise to the left. On TQt4, you can set the direction
+ // of the tqlayout to LTR (instead of inherit), but on TQt3
// the only way of fixing it is inserting the widgets in reversed
- // order to the layout.
+ // order to the tqlayout.
//
// But... as an ugly hack, we can also display the "other" operation
// thats damm ugly, but will work as well :)
@@ -22,7 +22,7 @@
#include <kapplication.h>
#include <klocale.h>
-/* these includes are needed for Qt support */
+/* these includes are needed for TQt support */
#include <tqlabel.h>
#include <tqlayout.h>
@@ -144,7 +144,7 @@ ExerciseCompare::~ExerciseCompare()
kdDebug() << "destructor ExerciseCompare()" << endl;
#endif
- /* no need to delete any child widgets, Qt does it by itself */
+ /* no need to delete any child widgets, TQt does it by itself */
}
/** resets the current state, creates a new task and count the last task as